@@ -22,3 +22,6 @@ class TestPetStore:
         # print(response.json()
         # TO-DO: implement
         pass
+
+    def add_two(number):
+        return number + 2
