@@ -1,6 +1,10 @@
 import schemathesis
 
-schema = schemathesis.from_path('./test_openapi_paths/pet3.json')
+
+# before moved to data folder
+# schema = schemathesis.from_path('./test_openapi_paths/pet3.json')
+
+schema = schemathesis.from_path('./data/pet3.json')
 schema.base_url = "https://petstore3.swagger.io/api/v3/"
 
 
@@ -14,3 +18,7 @@ def test_api(case):
     print("***** ***** *****")
 
     case.validate_response(response)
+
+
+def add_one(number):
+    return number + 1
